@@ -665,15 +665,6 @@ load(ImlibImage * im, ImlibProgressFunction progress, char progress_granularity,
    return 1;
 }
 
-char
-save(ImlibImage * im, ImlibProgressFunction progress, char progress_granularity)
-{
-   return 0;
-   im = NULL;
-   progress = NULL;
-   progress_granularity = 0;
-}
-
 /* fills the ImlibLoader struct with a strign array of format file */
 /* extensions this loader can load. eg: */
 /* loader->formats = { "jpeg", "jpg"}; */
